def get_blood_pressure_fields():
    return [
        "sys_blood_pressure_one",
        "dia_blood_pressure_one",
        "sys_blood_pressure_two",
        "dia_blood_pressure_two",
        "severe_htn",
    ]


def get_respiratory_o2_fields():
    return ["respiratory_rate"]
