# Generated by Django 4.2.11 on 2024-05-15 23:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0194_remove_glucosefbg_assay_datetime_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="glucosefbg",
            name="fbg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="FBG date/time measured"
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucosefbg",
            name="fbg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="FBG date/time measured"
            ),
        ),
    ]
