# Generated by Django 3.2.13 on 2022-09-08 15:26

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0147_auto_20220907_1505"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="refill_end_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Leave blank to auto-calculate if refilling to the next scheduled visit",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="refill_to_next_visit",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                help_text="If YES, leave refill end date blank to auto-calculate",
                max_length=25,
                verbose_name="Refill to the next scheduled visit",
            ),
        ),
        migrations.AlterField(
            model_name="studymedication",
            name="refill_end_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Leave blank to auto-calculate if refilling to the next scheduled visit",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="studymedication",
            name="refill_to_next_visit",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                help_text="If YES, leave refill end date blank to auto-calculate",
                max_length=25,
                verbose_name="Refill to the next scheduled visit",
            ),
        ),
    ]
