# Generated by Django 4.1.2 on 2023-03-01 18:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_ae", "0017_auto_20221130_2257"),
    ]

    operations = [
        migrations.AlterField(
            model_name="deathreporttmg",
            name="cause_of_death_agreed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If No, explain in the narrative below",
                max_length=15,
                null=True,
                verbose_name="Is the cause of death agreed between study doctor and TMG member?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmg",
            name="cause_of_death_agreed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If No, explain in the narrative below",
                max_length=15,
                null=True,
                verbose_name="Is the cause of death agreed between study doctor and TMG member?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmgsecond",
            name="cause_of_death_agreed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If No, explain in the narrative below",
                max_length=15,
                null=True,
                verbose_name="Is the cause of death agreed between study doctor and TMG member?",
            ),
        ),
    ]
