# Generated by Django 3.0.4 on 2020-04-20 15:16

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0029_auto_20200420_1751"),
    ]

    operations = [
        migrations.AlterField(
            model_name="coronakap",
            name="diabetic_dx_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MaxValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first learn you had <u>diabetes</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="hiv_pos_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MaxValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first test positive?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="hypertensive_dx_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MaxValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first learn you had <u>hypertension</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="shared_housing_one",
            field=models.IntegerField(
                help_text="Family / people who typically spend more than 14 nights per month in your home.",
                verbose_name="How many people live together in your home / dwelling?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="shared_housing_two",
            field=models.IntegerField(
                help_text="Visitors, friends, relatives, etc",
                verbose_name="In a typical month, how many <u>additional people</u> spend more than one night in your home / dwelling?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="diabetic_dx_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MaxValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first learn you had <u>diabetes</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="hiv_pos_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MaxValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first test positive?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="hypertensive_dx_year",
            field=models.IntegerField(
                blank=True,
                help_text="format YYYY",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1950),
                    django.core.validators.MaxValueValidator(2020),
                ],
                verbose_name="If 'Yes', what year did you first learn you had <u>hypertension</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="shared_housing_one",
            field=models.IntegerField(
                help_text="Family / people who typically spend more than 14 nights per month in your home.",
                verbose_name="How many people live together in your home / dwelling?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="shared_housing_two",
            field=models.IntegerField(
                help_text="Visitors, friends, relatives, etc",
                verbose_name="In a typical month, how many <u>additional people</u> spend more than one night in your home / dwelling?",
            ),
        ),
    ]
