# Generated by Django 4.1.2 on 2022-10-12 03:40

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0056_alter_historicalscreeningpartone_agree_to_p3_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="calculated_egfr_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mL/min/1.73m2 (system calculated)",
                max_digits=10,
                null=True,
                verbose_name="eGFR",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="converted_creatinine_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="μmol/L (micromoles/L) (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Serum creatinine",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="converted_fbg2_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Repeat FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="converted_fbg_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="converted_ogtt2_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Repeat OGTT (2-hours)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="converted_ogtt_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="OGTT (2-hours)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Creatinine level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="calculated_egfr_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mL/min/1.73m2 (system calculated)",
                max_digits=10,
                null=True,
                verbose_name="eGFR",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="converted_creatinine_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="μmol/L (micromoles/L) (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Serum creatinine",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="converted_fbg2_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Repeat FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="converted_fbg_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="converted_ogtt2_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Repeat OGTT (2-hours)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="converted_ogtt_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="OGTT (2-hours)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Creatinine level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="calculated_egfr_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mL/min/1.73m2 (system calculated)",
                max_digits=10,
                null=True,
                verbose_name="eGFR",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="converted_creatinine_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="μmol/L (micromoles/L) (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Serum creatinine",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="converted_fbg2_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Repeat FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="converted_fbg_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="converted_ogtt2_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Repeat OGTT (2-hours)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="converted_ogtt_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="OGTT (2-hours)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Creatinine level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="calculated_egfr_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mL/min/1.73m2 (system calculated)",
                max_digits=10,
                null=True,
                verbose_name="eGFR",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="converted_creatinine_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="μmol/L (micromoles/L) (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Serum creatinine",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="converted_fbg2_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Repeat FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="converted_fbg_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="converted_ogtt2_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Repeat OGTT (2-hours)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="converted_ogtt_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="OGTT (2-hours)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Creatinine level",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="calculated_egfr_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mL/min/1.73m2 (system calculated)",
                max_digits=10,
                null=True,
                verbose_name="eGFR",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="converted_creatinine_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="μmol/L (micromoles/L) (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Serum creatinine",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="converted_fbg2_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Repeat FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="converted_fbg_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="converted_ogtt2_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="Repeat OGTT (2-hours)",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="converted_ogtt_value",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=10,
                null=True,
                verbose_name="OGTT (2-hours)",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Creatinine level",
            ),
        ),
    ]
