# Generated by Django 3.2.11 on 2022-03-10 01:39

import edc_model.validators.date
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_prn", "0019_auto_20220309_2230"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalpregnancynotification",
            name="may_contact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                default="Yes",
                help_text="If YES/UNSURE, a visit will be scheduled on the EDD. If NO, the participant will be taken off study now",
                max_length=15,
                verbose_name="Has the participant agreed to be contacted to provide information on the delivery and birth outcomes?",
            ),
        ),
        migrations.AddField(
            model_name="pregnancynotification",
            name="may_contact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                default="Yes",
                help_text="If YES/UNSURE, a visit will be scheduled on the EDD. If NO, the participant will be taken off study now",
                max_length=15,
                verbose_name="Has the participant agreed to be contacted to provide information on the delivery and birth outcomes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancynotification",
            name="edd",
            field=models.DateField(
                validators=[edc_model.validators.date.date_is_future],
                verbose_name="Estimated date of delivery",
            ),
        ),
        migrations.AlterField(
            model_name="pregnancynotification",
            name="edd",
            field=models.DateField(
                validators=[edc_model.validators.date.date_is_future],
                verbose_name="Estimated date of delivery",
            ),
        ),
    ]
