# Generated by Django 5.0 on 2024-01-11 01:42

from django.db import migrations
from django.db.migrations import RunPython


def update_model_name(apps, schema_editor):
    model_cls = apps.get_model("meta_consent.subjectconsent")
    model_cls.objects.update(model_name="meta_consent.subjectconsent")


class Migration(migrations.Migration):
    dependencies = [
        ("meta_consent", "0020_historicalsubjectconsent_model_name_and_more"),
    ]

    operations = [RunPython(update_model_name)]
