# Generated by Django 4.2.11 on 2024-07-27 00:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0007_alter_endpoints_endpoint_label_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="endpoints",
            name="endpoint_label",
            field=models.CharField(max_length=250, null=True),
        ),
    ]
