# Generated by Django 4.2.11 on 2024-05-16 00:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0199_auto_20240516_0247"),
    ]

    operations = [
        migrations.RenameField(
            model_name="bloodresultsins",
            old_name="fasting_duration_minutes",
            new_name="fasting_duration_delta",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="fasting_duration_minutes",
            new_name="fasting_duration_delta",
        ),
        migrations.RenameField(
            model_name="glucosefbg",
            old_name="fasting_duration_minutes",
            new_name="fasting_duration_delta",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsins",
            old_name="fasting_duration_minutes",
            new_name="fasting_duration_delta",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="fasting_duration_minutes",
            new_name="fasting_duration_delta",
        ),
        migrations.RenameField(
            model_name="historicalglucosefbg",
            old_name="fasting_duration_minutes",
            new_name="fasting_duration_delta",
        ),
    ]
